"use strict";

require("core-js/modules/es.array-buffer.slice.js");

require("core-js/modules/es.typed-array.uint32-array.js");

require("core-js/modules/es.typed-array.sort.js");

require("core-js/modules/es.typed-array.to-locale-string.js");

require("core-js/modules/es.promise.js");

var _react = require("@testing-library/react");

var _TreeGrid = _interopRequireDefault(require("./TreeGrid"));

var _react2 = _interopRequireDefault(require("react"));

var _ej2ReactTreegrid = require("@syncfusion/ej2-react-treegrid");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const mGetRandomValues = jest.fn().mockReturnValueOnce(new Uint32Array(10));
Object.defineProperty(window, 'crypto', {
  value: {
    getRandomValues: mGetRandomValues
  }
}); //getRandomValue is mocked as it was called in syncfusion/treegrid and throwing err 

describe('rendering of components', () => {
  test('treegrid component is rendered', () => {
    (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_TreeGrid.default, null));
  });
  test('Syncfusion treegrid is rendered', () => {
    (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_ej2ReactTreegrid.TreeGridComponent, null));
  });
});
describe('Treegrid wrapper behaviour', () => {
  test('expand button is rendered intitially', () => {
    const {
      queryByTestId,
      queryByPlaceholderText
    } = (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_TreeGrid.default, null));
    expect(queryByTestId("expandbutton")).toBeTruthy();
  });
  test('collapsed button is rendered when grid is expanded', () => {
    const {
      queryByTestId,
      queryByPlaceholderText
    } = (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_TreeGrid.default, null));

    _react.fireEvent.click(_react.screen.queryByTestId("expandbutton"));

    expect(queryByTestId("collapsebutton")).toBeTruthy();
    expect(queryByTestId("expandbutton")).toBeFalsy();
  });
  test('width of wrapper is collapsed initially', () => {
    (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_TreeGrid.default, null));
    expect(_react.screen.getByTestId("treegrid-container")).toHaveClass("TreeGrid-container-short");
  });
  test('width of wrapper is expanded when expand button is clicked', () => {
    (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_TreeGrid.default, null));

    _react.fireEvent.click(_react.screen.queryByTestId("expandbutton"));

    expect(_react.screen.getByTestId("treegrid-container")).toHaveClass("TreeGrid-container-expanded");
  });
});
describe('Treegrid header behaviour', () => {
  test('header text is hidden when collapsed', async () => {
    const {
      container
    } = (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_TreeGrid.default, null));
    await new Promise(r => setTimeout(r, 100));
    expect(container.getElementsByClassName('hide-treegridheader').length).toBeGreaterThan(0);
  });
  test('header text is visible when expanded', () => {
    const {
      container
    } = (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_TreeGrid.default, null));

    _react.fireEvent.click(_react.screen.queryByTestId("expandbutton"));

    expect(container.getElementsByClassName('show-treegridheader').length).toBeGreaterThan(0);
  });
});
describe('Treegrid content overflow behaviour', () => {
  test('overflow is hidden when collapsed', async () => {
    const {
      container
    } = (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_TreeGrid.default, null));
    await new Promise(r => setTimeout(r, 100));
    expect(container.getElementsByClassName('hide-contentoverflow').length).toBeGreaterThan(0);
  });
  test('overflow is auto when expanded', () => {
    const {
      container
    } = (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_TreeGrid.default, null));

    _react.fireEvent.click(_react.screen.queryByTestId("expandbutton"));

    expect(container.getElementsByClassName('show-contentoverflow').length).toBeGreaterThan(0);
  });
});
describe.skip('Treegrid border behaviour', () => {
  test('vertical border is hidden when collapsed', async () => {
    const {
      container
    } = (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_TreeGrid.default, null));

    _react.fireEvent.click(_react.screen.queryByTestId("expandbutton"));

    _react.fireEvent.click(_react.screen.queryByTestId("collapsebutton"));

    await new Promise(r => setTimeout(r, 1000));
    expect(container.getElementsByClassName('hide-treegridborder').length).toBeGreaterThan(0);
  });
  test('vertical border is visible when expanded', async () => {
    const {
      container
    } = (0, _react.render)( /*#__PURE__*/_react2.default.createElement(_TreeGrid.default, null));

    _react.fireEvent.click(_react.screen.queryByTestId("expandbutton"));

    await new Promise(r => setTimeout(r, 1000));
    expect(container.getElementsByClassName('show-treegridborder').length).toBeGreaterThan(0);
  });
});